# Turkish Citizen Number Generator & Validator

Turkish citizen idendity number generator and validator python package for test purposes only

call generator function without arguments
```commandline
generator()

:returns
28210487...
```

call validator function with any tckn as a string which you want to test
returns a tuple which holds bool and tckn:str value
```commandline
validator('tckn')
:returns
(True, '28210487...')
```

# Contributors

[![Github](https://img.shields.io/badge/Github-red?style=flat&logo=github)](https://github.com/kadirkaya28)
&nbsp;
[Kadir Kaya](https://github.com/kadirkaya28)
